// Author: Vahe Mamyan
// -------------------------------------------------------------------

#ifndef TSHMSAnalysis_hh
#define TSHMSAnalysis_hh

#include <vector>
#include "G4ThreeVector.hh"
//-----------------------------------------------------------------------------
#include <fstream>

class TSHMSAnalysisManager
{
public:
  virtual ~TSHMSAnalysisManager();

  // method to call to create an instance of this class
  static TSHMSAnalysisManager* getInstance();

  G4double  GettTankFrontZ() { return TankFrontZ; }
  G4double  GetSHMSP0()      { return SHMS_P0; }

  G4bool getPMTon() { return PMTon; }

  // The CerTank is offset from transport coordinates
  // These functions will be used to move between Tank
  // coordinates and Transport coordinates
  void SetTankOffset() {TankOffset[0] = 5.0*cm;TankOffset[1]=0;TankOffset[2]=0;}
  G4double TankToTransportX(G4double X) {return X+TankOffset[0];}
  G4double TankToTransportY(G4double Y) {return Y+TankOffset[1];}
  G4double TankToTransportZ(G4double Z) {return Z+TankOffset[2];}
  
  G4double TransportToTankX(G4double X) {return X-TankOffset[0];}
  G4double TransportToTankY(G4double Y) {return Y-TankOffset[1];}
  G4double TransportToTankZ(G4double Z) {return Z-TankOffset[2];}

 //  void  print() { G4cout << " ROOT Interface " << G4endl; }
  void  SetCerHits( G4double nHits ) { fHMSCerNPE = nHits;}
  void  SetCerPmt1Adc( G4double adc ) { fHMSCerAdc1 = adc;}
  void  SetCerPmt2Adc( G4double adc ) { fHMSCerAdc2 = adc;}
//   void  SetCaloX( G4double x ) { fHMSCaloX = x;}
//   void  SetCaloY( G4double y ) { fHMSCaloY = y;}
//   void  SetHMSP(  G4double p ) { fHMSMomentum = p;}
//   void  SetCaloAdc ( G4float *pAdc ) { for( int i = 0; i < 78; i++) fCaloAdc[i]=pAdc[i]; }

//   void  SetS1XAdc ( G4float *pAdc ) { for( int i = 0; i < 32; i++) fHodoS1X[i]=pAdc[i]; }
//   void  SetS1YAdc ( G4float *pAdc ) { for( int i = 0; i < 20; i++) fHodoS1Y[i]=pAdc[i]; }
//   void  SetS2XAdc ( G4float *pAdc ) { for( int i = 0; i < 32; i++) fHodoS2X[i]=pAdc[i]; }
//   void  SetS2YAdc ( G4float *pAdc ) { for( int i = 0; i < 20; i++) fHodoS2Y[i]=pAdc[i]; }
//   void  SetHodoDE ( G4float *pDE  ) { for( int i = 0; i < 4 ; i++) fHodo_dE[i]=pDE[i];  }

  void  SetTankFrontZ( G4double Z ) { TankFrontZ = Z ; }
  void  SetSHMSP0( G4double P0 ) { SHMS_P0 = P0; }

  std::ofstream  fout_cer;
  std::ofstream  fout_hit;

  // Added variables to take advantage of static property of class
  G4bool Bin;			// Flag indicating to output a binary or text file out
  G4bool PMTon;
  G4int  EventNumber;	// This keeps track of the event number
  G4double PMT[4][3];	// This is the position of the four PMTs in cm
  G4double PMTAng[4];	// This is the angle of the four PMTs
  G4double PMTR;		// This is the radius of the PMT in cm

  G4double TankOffset[3];

  char  Particle[10];


private:
  //private constructor in order to create a singleton

  TSHMSAnalysisManager();
  static TSHMSAnalysisManager* instance;

  //---------------------------------------------------------------------------

  G4double fHMSCaloEtot;
  G4double fHMSCaloLayer1DE;
  G4double fHMSCaloLayer2DE;
  G4double fHMSCaloLayer3DE;
  G4double fHMSCaloLayer4DE;
  G4double fHMSCaloParticle;
  G4double fHMSCaloMomentum;
  G4double fHMSCerEnergyDep;
  G4double fHMSCerNPE;
  G4double fHMSCerAdc1;
  G4double fHMSCerAdc2;
  
  G4double fHMSCaloX;
  G4double fHMSCaloY;
  G4double fHMSMomentum;

  G4float  fCaloAdc[78];

  G4float  fHodoS1X[32];
  G4float  fHodoS1Y[20];
  G4float  fHodoS2X[32];
  G4float  fHodoS2Y[20];

  G4float  fHodo_dE[4]; // 0->S1X, 1->S1Y, 2->S2X, 3->S2Y

  // -- 
  G4double SHMS_P0; // central momentum
  G4double TankFrontZ; // Cerenkov tank front face position fixed

};

#endif
