
#ifndef TSHMSCerenkov_h
#define TSHMSCerenkov_h 1

#include "globals.hh"
#include "G4VUserDetectorConstruction.hh"
#include "G4ThreeVector.hh"
#include "G4RotationMatrix.hh"

class G4Box;
class G4Paraboloid;
class G4LogicalVolume;
class G4VPhysicalVolume;
class G4Material;
class TSHMSDetectorMessenger;
class G4Tubs;
class G4IntersectionSolid;
class G4SubtractionSolid;
class TSHMSAnalysisManager;
class TSHMSPmtSD;

#define X_AXIS 0
#define Y_AXIS 1
#define Z_AXIS 2

#define MIRROR_1 0
#define MIRROR_2 1
#define MIRROR_3 2
#define MIRROR_4 3
//-----------------------------------------------------------------------------------
class TSHMSCerenkov
{
  public:
  TSHMSCerenkov();
  ~TSHMSCerenkov();

  public:
  
  G4VPhysicalVolume* ConstructCerenkov( G4VPhysicalVolume* , G4LogicalVolume* , G4ThreeVector );

  // Some get methods for later need
  //
  //
  G4IntersectionSolid* MakeMirrorSolid( G4double *boxSize , G4double *sphSize );
  G4IntersectionSolid* MakeMirrorParabola( G4double *boxSize , G4double *sphSize );
  G4Box* MakeMirrorSolidTest( G4double *boxSize , G4double *sphSize );
  G4Paraboloid* MakeMirrorParabolaTest( G4double *boxSize , G4double *sphSize );
  
  void      Init();
  G4double  GetZposition() { return ( FrontOfTank + TankLength / 2.0 ) *cm; }

  void      MakePlanes( G4double PMT_pos[][3] , G4RotationMatrix *PMTrot , G4int NPlanes , G4double DistOfPl );
  
  void 		BackPlane(G4double, G4double);
  private:

  G4Tubs*            solidCerTubs;     // pointer to the solid Chamber
  G4LogicalVolume*   logicCerTubs;     // pointer to the logical Chamber
  G4VPhysicalVolume* physiCerTubs;     // pointer to the physical Chamber

  G4Tubs*            solidCerMirror;   // pointer to the solid Chamber
  G4LogicalVolume*   logicCerMirror;   // pointer to the logical Chamber
  G4VPhysicalVolume* physiCerMirror;   // pointer to the physical Chamber

  G4Tubs*            solidCerPMT;     // pointer to the solid Chamber
  G4LogicalVolume*   logicCerPMT;     // pointer to the logical Chamber
  G4VPhysicalVolume* physiCerPMT;     // pointer to the physical Chamber

  G4Tubs*            solidPMTCathode;     // pointer to the solid Chamber
  G4LogicalVolume*   logicPMTCathode;     // pointer to the logical Chamber
  G4VPhysicalVolume* physiPMTCathode;     // pointer to the physical Chamber

  // -- Tank
  G4double  FrontOfTank;
  G4double  TankLength;
  G4double  DisMirToBackWindow;
  G4double  TankInnerDiameter;
  
  // -- Mirror
  // We want to create new variables as to ensure that we orient the mirrors correctly
  // Paul Selles - May 6/09 
  G4double  MirrorF;       // Mirror focal point to be use to implement parabolic in future
  G4double  MirrorR;

  G4bool    MirrorSphere;
  G4bool    MirrorCorner;
  G4bool    PMTon;
  G4bool    PMTauto;

  // We are going to build to mirrors based on their position in the
  // Cerenkov vessel of the center most point to the outer most point
  G4double MirrorStart[4][3];
  G4double MirrorEnd[4][3];
  G4double MirrorWidth[4][3];

  // Here we have the dimensions of the mirror wrt the x,y,z coordinate system
  // of the Cerenkov tank
  G4double Mirror[4][3];
  G4double MirrorPosition[4][3];

  // Here we have the tilt angles of the mirrors about the axes mentioned
  G4double MirrorAngle[4];

  G4int     NumPlanes;
  G4double  PlaneDistance;

  // -- PMT
  G4double  Window_R;
  G4double  PMT_R;
  G4double  PMT_L;
  G4double  Cathode_R;
  G4double  Cathode_L;

  G4double PMTPosition[4][3];
  G4double PMTAngle[4];
  
  G4double PMTWindowPos[4][3];
  G4double PMTCathodePos[4][3];
  G4double PMTFlangePos[4][3];
  G4double PMTBackingPos[4][3];

  G4double Overlap;

  static TSHMSPmtSD* aPmtSD;
  
  TSHMSAnalysisManager* analysis;   // For data management 

};

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#endif
