/* This is an example of the header file of a hit class as per
 * dictated in page 118 of GEANT4 user manual  Paul Selles
 */

#ifndef TSHMSPmtHit_hh
#define TSHMSPmtHit_hh 1

#include "G4VHit.hh"
#include "G4THitsCollection.hh"
#include "G4ThreeVector.hh"
#include "G4Allocator.hh"

class TSHMSAnalysisManager;

class TSHMSPmtHit : public G4VHit
{
	public:
		TSHMSPmtHit();
		virtual ~TSHMSPmtHit();
		TSHMSPmtHit(const TSHMSPmtHit &right);
		const TSHMSPmtHit& operator=(const TSHMSPmtHit &right);
		int operator==(const TSHMSPmtHit &right) const;

		inline void *operator new(size_t);
		inline void operator delete(void *aHit);

		virtual void Draw();
		virtual void Print();
	private:
		//G4double edep;
		G4double time;
		G4int TrackID;
		G4ThreeVector pos;
		G4ThreeVector localPos;
		G4ThreeVector worldPos;
    public:
		//inline void SetEdep(G4double de) {edep = de;}
		//inline G4double GetEdep() const {return edep;}
		
		inline G4ThreeVector GetPos() const {return pos;}
		inline void SetPos(G4ThreeVector xyz) {pos = xyz;}
      
		inline void SetTime(G4double t) {time = t; }
		inline G4double GetTime() const { return time; }
		inline void SetLocalPos(G4ThreeVector xyz) { localPos = xyz; }
        inline G4ThreeVector GetLocalPos() const { return localPos; }
        inline void SetWorldPos(G4ThreeVector xyz) { worldPos = xyz; }
        inline G4ThreeVector GetWorldPos() const { return worldPos; }

		inline void SetTrackID(G4int ID) {TrackID = ID;}
		inline G4int GetTrackID() const { return TrackID;}
  
		TSHMSAnalysisManager* analysis;   // For data management 
};

typedef G4THitsCollection<TSHMSPmtHit> TSHMSPmtHitCollection;

extern G4Allocator<TSHMSPmtHit> TSHMSPmtHitAllocator;

inline void* TSHMSPmtHit::operator new(size_t)
{
	void *aHit;
	aHit = (void*) TSHMSPmtHitAllocator.MallocSingle();
	return aHit;
}
inline void TSHMSPmtHit::operator delete(void *aHit)
{
	TSHMSPmtHitAllocator.FreeSingle((TSHMSPmtHit*) aHit);
}

#endif
