//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id: TSHMSPrimaryGeneratorAction.hh,v 1.7 2006/06/29 17:47:43 gunter Exp $
// GEANT4 tag $Name: geant4-08-02 $
//
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
#ifndef TSHMSPrimaryGeneratorAction_h
#define TSHMSPrimaryGeneratorAction_h 1

#include "G4VUserPrimaryGeneratorAction.hh"
#include "TSHMSAnalysisManager.hh"

class TSHMSDetectorConstruction;
class G4ParticleGun;
class G4Event;

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
class TSHMSPrimaryGeneratorAction : public G4VUserPrimaryGeneratorAction
{
public:
  TSHMSPrimaryGeneratorAction(TSHMSDetectorConstruction*);    
  ~TSHMSPrimaryGeneratorAction();

  void TSHMSReadTransportMatrix();
  void TSHMSTransportToCerenkov( G4double &x , G4double &y , G4double &z , G4double &px , G4double &py , G4double &pz , G4double &Pmom );
  
public:
  void GeneratePrimaries(G4Event*);
  void ReadGeneratedEvents(G4int);
private:
  G4ParticleGun* particleGun;
  TSHMSDetectorConstruction* myDetector;
  TSHMSAnalysisManager* analysisManager;
  G4double R[6][6];
  G4double T[6][6][6];

  G4double *pHsyfp;
  G4double *pHsxfp;
  G4double *pHsypfp;
  G4double *pHsxpfp;
  G4double *pHsyCerp; // Cerenkov front face
  G4double *pHsxCerp; // Cerenkov front face
  G4double *pHsdelta;
  G4bool    UseGenerated; // True if use generated events false use transport matrix
};

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#endif


