#ifndef TSHMSTrackerHit_h
#define TSHMSTrackerHit_h 1

#include "G4VHit.hh"
#include "G4THitsCollection.hh"
#include "G4Allocator.hh"
#include "G4ThreeVector.hh"

class TSHMSTrackerHit : public G4VHit
{
  public:

      TSHMSTrackerHit();
     ~TSHMSTrackerHit();
      TSHMSTrackerHit(const TSHMSTrackerHit&);
      const TSHMSTrackerHit& operator=(const TSHMSTrackerHit&);
      G4int operator==(const TSHMSTrackerHit&) const;

      inline void* operator new(size_t);
      inline void  operator delete(void*);

      void Draw();
      void Print();

  public:
  
      void SetTrackID  (G4int track)      { trackID = track; };
      void SetChamberNb(G4int chamb)      { chamberNb = chamb; };  
      void SetEdep     (G4double de)      { edep = de; };
      void SetPos      (G4ThreeVector xyz){ pos = xyz; };
      
      G4int GetTrackID()    { return trackID; };
      G4int GetChamberNb()  { return chamberNb; };
      G4double GetEdep()    { return edep; };      
      G4ThreeVector GetPos(){ return pos; };
      
  private:
  
      G4int         trackID;
      G4int         chamberNb;
      G4double      edep;
      G4ThreeVector pos;
};

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

typedef G4THitsCollection<TSHMSTrackerHit> TSHMSTrackerHitsCollection;

extern G4Allocator<TSHMSTrackerHit> TSHMSTrackerHitAllocator;

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

inline void* TSHMSTrackerHit::operator new(size_t)
{
  void *aHit;
  aHit = (void *) TSHMSTrackerHitAllocator.MallocSingle();
  return aHit;
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

inline void TSHMSTrackerHit::operator delete(void *aHit)
{
  TSHMSTrackerHitAllocator.FreeSingle((TSHMSTrackerHit*) aHit);
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#endif
